@@ -1,11 +1,12 @@
 package Lingua::Word::Parser;
+our $AUTHORITY = 'cpan:GENE';
 
 # ABSTRACT: Parse a word into known and unknown parts
 
 use strict;
 use warnings;
 
-our $VERSION = '0.07';
+our $VERSION = '0.08';
 
 use Bit::Vector;
 use DBI;
@@ -206,16 +207,45 @@ sub score {
 
     for my $mask ( keys %$parts ) {
         for my $element ( @{ $parts->{$mask} } ) {
-            my $key  = "$element->{score}{knowns}:$element->{score}{unknowns} chunks / $element->{score}{knownc}:$element->{score}{unknownc} chars";
-            my $val  = join ', ', @{ $element->{partition} };
+            my $score = sprintf "%d:%d chunks / %d:%d chars",
+                $element->{score}{knowns}, $element->{score}{unknowns},
+                $element->{score}{knownc}, $element->{score}{unknownc};
+
+            my $familiarity = sprintf "%.2f chunks / %.2f chars", @{ $self->_familiarity($mask) };
+
+            my $part = join ', ', @{ $element->{partition} };
+
             my $defn = join ', ', @{ $element->{definition} };
-            push @{ $self->{score}{$mask} }, { score => $key, partition => $val, definition => $defn };
+
+            push @{ $self->{score}{$mask} }, {
+                score       => $score,
+                familiarity => $familiarity,
+                partition   => $part,
+                definition  => $defn,
+            };
         }
     }
 
     return $self->{score};
 }
 
+sub _familiarity {
+    my ( $self, $mask ) = @_;
+
+    my @chunks = split /(0+)/, $mask;
+
+    # Figure out how many chars are only 1s and
+    # Figure out how many chunks are made up of 1s:
+    my $char_1s = 0;
+    my $chunk_1s = 0;
+    for my $chunk (@chunks) {
+        $char_1s  += $chunk =~ /0/ ? 0 : length($chunk);
+        $chunk_1s += $chunk =~ /0/ ? 0 : 1;
+    }
+
+    return [ $chunk_1s / @chunks, $char_1s / length($mask) ];
+}
+
 
 sub score_parts {
     my $self = shift;
@@ -382,7 +412,7 @@ Lingua::Word::Parser - Parse a word into known and unknown parts
 
 =head1 VERSION
 
-version 0.07
+version 0.08
 
 =head1 SYNOPSIS
 
@@ -470,6 +500,13 @@ all masks.
 Score the known vs unknown word part combinations into ratios of characters and
 chunks or parts or "spans of adjacent characters" B<as a collection of strings>.
 
+This method sets the B<score> member to a list of hashrefs with keys:
+
+  partition
+  definition
+  score
+  familiarity
+
 If not given, the B<$open_sparator> and B<$close_separator> are '<' and '>' by
 default.
 
@@ -485,7 +522,7 @@ chunks (spans of adjacent characters).
 If not given, the B<$open_sparator> and B<$close_separator> are '<' and '>' by
 default.
 
-The line terminator can be any string, like a newline (C<\n> or an HTML
+The B<$line_terminator> can be any string, like a newline (C<\n> or an HTML
 line-break), but is the empty string (C<''>) by default.
 
 =head1 SEE ALSO
@@ -496,13 +533,15 @@ L<http://en.wikipedia.org/wiki/Affix> is the tip of the iceberg...
 
 L<https://github.com/ology/Word-Part> a friendly L<Dancer> user interface.
 
+The F<t/*> and F<eg/*> files in this distribution!
+
 =head1 AUTHOR
 
 Gene Boggs <gene@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2014 by Gene Boggs.
+This software is copyright (c) 2015 by Gene Boggs.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
